/****************************************************************************
    
    This file is part of The Newtonator soft synth.

    Copyright (C) 2010-2011 Michael Bechard <mbechard@users.sourceforge.net>

    The Newtonator is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Newtonator is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with The Newtonator.  If not, see <http://www.gnu.org/licenses/>.

****************************************************************************/

#ifndef SELECTION_WIDGET_H
#define SELECTION_WIDGET_H

#include <gtkmm/box.h>
#include <gtkmm/combobox.h>
#include <gtkmm/liststore.h>
#include <gtkmm/treemodel.h>
#include <stk/Stk.h>
#include "control_enum.h"

class NewtParentWidget;

template <class T>
class SelectionWidget : public Gtk::HBox
{
    public:

    SelectionWidget(Glib::ustring label, NewtParentWidget* parent, ControlEnum ctrlID);

    virtual ~SelectionWidget() {}

    void AddItems(T ids[], const char* names[], int num);
    T GetActive();
    void SetActive(T id);
    typedef sigc::signal<void> type_signal_changed;
    inline type_signal_changed signal_changed() { return m_signalChanged; }

    protected:

    class Columns : public Gtk::TreeModel::ColumnRecord
    {
        public:

        Columns() { add(m_id); add(m_name); }

        Gtk::TreeModelColumn<T> m_id;
        Gtk::TreeModelColumn<Glib::ustring> m_name;
    };

    void AddItem(T id, Glib::ustring name);
    void on_value_should_change(ControlEnum ctrl, stk::StkFloat val);
    void on_signal_changed();

    NewtParentWidget* m_parent;

    private:

    Columns m_cbColumns;
    Glib::RefPtr<Gtk::ListStore> m_refCBTreeModel;
    Gtk::Label m_label;
    ControlEnum m_ctrlID;
    Gtk::ComboBox m_comboBox;
    type_signal_changed m_signalChanged;
};

#endif // SELECTION_WIDGET_H
